This module provides utility functions and common lexer rules.
Macros
- match_
string - Creates a lexer rule that matches a specific string.
- match_
word - Creates a lexer rule that matches a specific word. Words are the sequences of strings that are separated by a space.
- rules_
vec - Creates a vector of lexer rules.
Structs
- Skip
Whitespace Rule - A lexer rule that skips whitespace characters.