Struct Source 

pub struct Source<'a> {
    pub filename: &'a str,
    pub code: String,
}
Represents source code along with its filename.

Fields

filename: &'a str

The filename of the source code.

code: String

The actual source code as a string.

Implementations

Source

impl<'a> Source<'a>

pub fn new(filename: &'a str) -> Result<Self, Error>

Creates a new Source instance, reading the source code from the given filename.

pub fn from_str(filename: &'a str, code: &'a str) -> Self

Creates a new Source instance from a string slice.